Stan Math Library: stan/math/prim/scal/meta/value_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

value_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_VALUE_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_VALUE_TYPE_HPP
3
4 namespace stan {
5 namespace math {
6
17 template <typename T>
18 struct value_type {
19 };
20
27 template <typename T>
28 struct value_type<const T> {
29 typedef typename value_type<T>::type type;
30 };
31
32 }
33 }
34 #endif
stan::math::value_type< const T >::type
value_type< T >::type type
Definition: value_type.hpp:29
stan
Definition: log_sum_exp.hpp:8
stan::math::value_type
Primary template class for metaprogram to compute the type of values stored in a container.
Definition: value_type.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.